/*****************************************************************************

File:  NVIDIA_DEVICE_INFO.h

Copyright NVIDIA Corporation 2005
TO THE MAXIMUM EXTENT PERMITTED BY APPLICABLE LAW, THIS SOFTWARE IS PROVIDED
*AS IS* AND NVIDIA AND ITS SUPPLIERS DISCLAIM ALL WARRANTIES, EITHER EXPRESS
OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS FOR A PARTICULAR PURPOSE.  IN NO EVENT SHALL NVIDIA OR ITS SUPPLIERS
BE LIABLE FOR ANY SPECIAL, INCIDENTAL, INDIRECT, OR CONSEQUENTIAL DAMAGES
WHATSOEVER (INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS OF BUSINESS PROFITS,
BUSINESS INTERRUPTION, LOSS OF BUSINESS INFORMATION, OR ANY OTHER PECUNIARY LOSS)
ARISING OUT OF THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF NVIDIA HAS
BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.

******************************************************************************/

#ifndef NVIDIA_DEVICE_INFO_H
#define NVIDIA_DEVICE_INFO_H

#define DT_NVIDIA_VENDOR_ID 0x10DE
#define NVIDIA_DEVICE_TOTAL 192

typedef struct DEVICE_INFO {
  unsigned long   deviceID;
  unsigned long   gpuID;
  char* chipIDName;
  char* adaptorIDName;
} DEVICE_INFO;

static const DEVICE_INFO NVIDIA_DEVICE_INFO[] = {

  //Device ID    GPU ID    Chip ID name                       Adapter ID Name
  { 0x0020,      0x0000,   "RIVA TNT",                        "RIVA TNT"                        },
  { 0x0028,      0x0000,   "RIVA TNT2/TNT2 Pro",              "RIVA TNT2/TNT2 Pro"              },
  { 0x00A0,      0x0000,   "Aladdin TNT2",                    "Aladdin TNT2"                    },
  { 0x002C,      0x0000,   "Vanta/Vanta LT",                  "Vanta/Vanta LT"                  },
  { 0x0029,      0x0000,   "RIVA TNT2 Ultra",                 "RIVA TNT2 Ultra"                 },
  { 0x002D,      0x0000,   "RIVA TNT2 Model 64/Model 64 Pro", "RIVA TNT2 Model 64/Model 64 Pro" },
  { 0x0100,      0x0000,   "GeForce 256",                     "GeForce 256"                     },
  { 0x0101,      0x0000,   "GeForce DDR",                     "GeForce DDR"                     },
  { 0x0103,      0x0000,   "Quadro",                          "Quadro"                          },
  { 0x0110,      0x0000,   "GeForce2 MX/MX 400",              "GeForce2 MX/MX 400"              },
  { 0x0111,      0x0000,   "GeForce2 MX 100/200",             "GeForce2 MX 100/200"             },
  { 0x01A0,      0x0000,   "GeForce2 Integrated GPU",         "GeForce2 Integrated GPU"         },
  { 0x0150,      0x0000,   "GeForce2 GTS/GeForce2 Pro",       "GeForce2 GTS/GeForce2 Pro"       },
  { 0x0151,      0x0000,   "GeForce2 Ti",                     "GeForce2 Ti"                     },
  { 0x0152,      0x0000,   "GeForce2 Ultra",                  "GeForce2 Ultra"                  },
  { 0x0153,      0x0000,   "Quadro2 Pro",                     "Quadro2 Pro"                     },
  { 0x0170,      0x0000,   "GeForce4 MX 460",                 "GeForce4 MX 460"                 },
  { 0x0171,      0x0000,   "GeForce4 MX 440",                 "GeForce4 MX 440"                 },
  { 0x0172,      0x0000,   "GeForce4 MX 420",                 "GeForce4 MX 420"                 },
  { 0x0173,      0x0000,   "GeForce4 MX 440-SE",              "GeForce4 MX 440-SE"              },
  { 0x0178,      0x0000,   "Quadro4 550 XGL",                 "Quadro4 550 XGL"                 },
  { 0x017A,      0x0000,   "Quadro NVS",                      "Quadro NVS"                      },
  { 0x0181,      0x0000,   "GeForce4 MX 440 with AGP8X",      "GeForce4 MX 440 with AGP8X"      },
  { 0x0182,      0x0000,   "GeForce4 MX 440SE with AGP8X",    "GeForce4 MX 440SE with AGP8X"    },
  { 0x0183,      0x0000,   "GeForce4 MX 420 with AGP8X",      "GeForce4 MX 420 with AGP8X"      },
  { 0x0185,      0x0000,   "GeForce4 MX 4000",                "GeForce4 MX 4000"                },
  { 0x0188,      0x0000,   "Quadro4 580 XGL",                 "Quadro4 580 XGL"                 },
  { 0x018A,      0x0000,   "Quadro NVS with AGP8X",           "Quadro NVS with AGP8X"           },
  { 0x018B,      0x0000,   "Quadro4 380 XGL",                 "Quadro4 380 XGL"                 },
  { 0x018C,      0x0000,   "Quadro NVS 50 PCI",               "Quadro NVS 50 PCI"               },
  { 0x01F0,      0x0000,   "GeForce4 MX Integrated GPU",      "GeForce4 MX Integrated GPU"      },
  { 0x0200,      0x0000,   "GeForce3",                        "GeForce3"                        },
  { 0x0201,      0x0000,   "GeForce3 Ti 200",                 "GeForce3 Ti 200"                 },
  { 0x0202,      0x0000,   "GeForce3 Ti 500",                 "GeForce3 Ti 500"                 },
  { 0x0203,      0x0000,   "Quadro DCC",                      "Quadro DCC"                      },
  { 0x0250,      0x0000,   "GeForce4 Ti 4600",                "GeForce4 Ti 4600"                },
  { 0x0251,      0x0000,   "GeForce4 Ti 4400",                "GeForce4 Ti 4400"                },
  { 0x0252,      0x0000,   "NV25",                            "NV25"                            },
  { 0x0253,      0x0000,   "GeForce4 Ti 4200",                "GeForce4 Ti 4200"                },
  { 0x0258,      0x0000,   "Quadro4 900 XGL",                 "Quadro4 900 XGL"                 },
  { 0x0259,      0x0000,   "Quadro4 750 XGL",                 "Quadro4 750 XGL"                 },
  { 0x025B,      0x0000,   "Quadro4 700 XGL",                 "Quadro4 700 XGL"                 },
  { 0x0280,      0x0000,   "GeForce4 Ti 4800",                "GeForce4 Ti 4800"                },
  { 0x0281,      0x0000,   "GeForce4 Ti 4200 with AGP8X",     "GeForce4 Ti 4200 with AGP8X"     },
  { 0x0282,      0x0000,   "GeForce4 Ti 4800 SE",             "GeForce4 Ti 4800 SE"             },
  { 0x0288,      0x0000,   "Quadro4 980 XGL",                 "Quadro4 980 XGL"                 },
  { 0x0289,      0x0000,   "Quadro4 780 XGL",                 "Quadro4 780 XGL"                 },
  { 0x0301,      0x0000,   "GeForce FX 5800 Ultra",           "GeForce FX 5800 Ultra"           },
  { 0x0302,      0x0000,   "GeForce FX 5800",                 "GeForce FX 5800"                 },
  { 0x0308,      0x0000,   "Quadro FX 2000",                  "Quadro FX 2000"                  },
  { 0x0309,      0x0000,   "Quadro FX 1000",                  "Quadro FX 1000"                  },
  { 0x0311,      0x0000,   "GeForce FX 5600 Ultra",           "GeForce FX 5600 Ultra"           },
  { 0x0312,      0x0000,   "GeForce FX 5600",                 "GeForce FX 5600"                 },
  { 0x0313,      0x0000,   "NV31",                            "NV31"                            },
  { 0x0314,      0x0000,   "GeForce FX 5600XT",               "GeForce FX 5600XT"               },
  { 0x0320,      0x0000,   "GeForce FX 5200",                 "GeForce FX 5200"                 },
  { 0x0321,      0x0000,   "GeForce FX 5200 Ultra",           "GeForce FX 5200 Ultra"           },
  { 0x0322,      0x0000,   "GeForce FX 5200",                 "GeForce FX 5200"                 },
  { 0x0323,      0x0000,   "GeForce FX 5200LE",               "GeForce FX 5200LE"               },
  { 0x0326,      0x0000,   "GeForce FX 5500",                 "GeForce FX 5500"                 },
  { 0x0327,      0x0000,   "GeForce FX 5100",                 "GeForce FX 5100"                 },
  { 0x032A,      0x0000,   "Quadro NVS 280 PCI",              "Quadro NVS 280 PCI"              },
  { 0x032B,      0x0000,   "Quadro FX 500/FX 600",            "Quadro FX 500/FX 600"            },
  { 0x032F,      0x0000,   "NV34GL",                          "NV34GL"                          },
  { 0x0330,      0x0000,   "GeForce FX 5900 Ultra",           "GeForce FX 5900 Ultra"           },
  { 0x0331,      0x0000,   "GeForce FX 5900",                 "GeForce FX 5900"                 },
  { 0x0332,      0x0000,   "GeForce FX 5900XT",               "GeForce FX 5900XT"               },
  { 0x0333,      0x0000,   "GeForce FX 5950 Ultra",           "GeForce FX 5950 Ultra"           },
  { 0x0334,      0x0000,   "GeForce FX 5900ZT",               "GeForce FX 5900ZT"               },
  { 0x0338,      0x0000,   "Quadro FX 3000",                  "Quadro FX 3000"                  },
  { 0x033F,      0x0000,   "Quadro FX 700",                   "Quadro FX 700"                   },
  { 0x0341,      0x0000,   "GeForce FX 5700 Ultra",           "GeForce FX 5700 Ultra"           },
  { 0x0342,      0x0000,   "GeForce FX 5700",                 "GeForce FX 5700"                 },
  { 0x0343,      0x0000,   "GeForce FX 5700LE",               "GeForce FX 5700LE"               },
  { 0x0344,      0x0000,   "GeForce FX 5700VE",               "GeForce FX 5700VE"               },
  { 0x0345,      0x0000,   "NV36",                            "NV36"                            },
  { 0x034E,      0x0000,   "Quadro FX 1100",                  "Quadro FX 1100"                  },
  { 0x034F,      0x0000,   "NV36GL",                          "NV36GL"                          },
  { 0x0040,      0x0000,   "GeForce 6800 Ultra",              "GeForce 6800 Ultra"              },
  { 0x0041,      0x0000,   "GeForce 6800",                    "GeForce 6800"                    },
  { 0x0042,      0x0000,   "GeForce 6800 LE",                 "GeForce 6800 LE"                 },
  { 0x0043,      0x0000,   "NV40",                            "NV40"                            },
  { 0x0045,      0x0000,   "GeForce 6800 GT",                 "GeForce 6800 GT"                 },
  { 0x0049,      0x0000,   "NV40GL",                          "NV40GL"                          },
  { 0x004E,      0x0000,   "Quadro FX 4000",                  "Quadro FX 4000"                  },
  { 0x00C0,      0x0000,   "NV41",                            "NV41"                            },
  { 0x00C1,      0x0000,   "GeForce 6800",                    "GeForce 6800"                    },
  { 0x00C2,      0x0000,   "GeForce 6800 LE",                 "GeForce 6800 LE"                 },
  { 0x00CD,      0x0000,   "Quadro FX 3450/4000 SDI",         "Quadro FX 3450/4000 SDI"         },
  { 0x00CE,      0x0000,   "Quadro FX 1400",                  "Quadro FX 1400"                  },
  { 0x0140,      0x0000,   "GeForce 6600 GT",                 "GeForce 6600 GT"                 },
  { 0x0141,      0x0000,   "GeForce 6600",                    "GeForce 6600"                    },
  { 0x0142,      0x0000,   "NV43",                            "NV43"                            },
  { 0x0143,      0x0000,   "NV43",                            "NV43"                            },
  { 0x0145,      0x0000,   "GeForce 6610 XL",                 "GeForce 6610 XL"                 },
  { 0x014B,      0x0000,   "NV43",                            "NV43"                            },
  { 0x014C,      0x0000,   "NV43GL",                          "NV43GL"                          },
  { 0x014D,      0x0000,   "NV43GL",                          "NV43GL"                          },
  { 0x014E,      0x0000,   "Quadro FX 540",                   "Quadro FX 540"                   },
  { 0x014F,      0x0000,   "GeForce 6200",                    "GeForce 6200"                    },
  { 0x0160,      0x0000,   "NV44",                            "NV44"                            },
  { 0x0161,      0x0000,   "GeForce 6200 TurboCache(TM)",     "GeForce 6200 TurboCache(TM)"     },
  { 0x0162,      0x0000,   "NV44",                            "NV44"                            },
  { 0x0163,      0x0000,   "NV44",                            "NV44"                            },
  { 0x0165,      0x0000,   "Quadro NVS 285",                  "Quadro NVS 285"                  },
  { 0x016E,      0x0000,   "NV44GL",                          "NV44GL"                          },
  { 0x0220,      0x0000,   "NV44",                            "NV44"                            },
  { 0x0221,      0x0000,   "NV44",                            "NV44"                            },
  { 0x0222,      0x0000,   "NV44",                            "NV44"                            },
  { 0x0211,      0x0000,   "GeForce 6800",                    "GeForce 6800"                    },
  { 0x0212,      0x0000,   "GeForce 6800 LE",                 "GeForce 6800 LE"                 },
  { 0x0215,      0x0000,   "GeForce 6800 GT",                 "GeForce 6800 GT"                 },
  { 0x00F0,      0x0040,   "GeForce 6800 Ultra",              "GeForce 6800 Ultra"              },
  { 0x00F0,      0x0041,   "GeForce 6800",                    "GeForce 6800"                    },
  { 0x00F1,      0x0000,   "GeForce 6600 GT",                 "GeForce 6600 GT"                 },
  { 0x00F1,      0x0140,   "GeForce 6600 GT",                 "GeForce 6600 GT"                 },
  { 0x00F2,      0x0000,   "GeForce 6600",                    "GeForce 6600"                    },
  { 0x00F2,      0x0141,   "GeForce 6600",                    "GeForce 6600"                    },
  { 0x00F3,      0x0000,   "GeForce 6200",                    "GeForce 6200"                    },
  { 0x00F3,      0x014F,   "GeForce 6200",                    "GeForce 6200"                    },
  { 0x00F8,      0x0000,   "Quadro FX 3400/4400",             "Quadro FX 3400/4400"             },
  { 0x00F8,      0x004D,   "Quadro FX 4400",                  "Quadro FX 4400"                  },
  { 0x00F8,      0x004E,   "Quadro FX 3400",                  "Quadro FX 3400"                  },
  { 0x00F9,      0x0000,   "GeForce 6800 Series GPU",         "GeForce 6800 Series GPU"         },
  { 0x00F9,      0x0040,   "GeForce 6800 Ultra",              "GeForce 6800 Ultra"              },
  { 0x00F9,      0x0045,   "GeForce 6800 GT",                 "GeForce 6800 GT"                 },
  { 0x00FA,      0x0000,   "GeForce PCX 5750",                "GeForce PCX 5750"                },
  { 0x00FA,      0x0341,   "GeForce PCX 5750",                "GeForce PCX 5750"                },
  { 0x00FB,      0x0000,   "GeForce PCX 5900",                "GeForce PCX 5900"                },
  { 0x00FB,      0x0331,   "GeForce PCX 5900",                "GeForce PCX 5900"                },
  { 0x00FC,      0x0000,   "GeForce PCX 5300",                "GeForce PCX 5300"                },
  { 0x00FC,      0x0322,   "GeForce PCX 5300",                "GeForce PCX 5300"                },
  { 0x00FC,      0x032B,   "Quadro FX 330",                   "Quadro FX 330"                   },
  { 0x00FD,      0x0000,   "Quadro PCI-E Series",             "Quadro PCI-E Series"             },
  { 0x00FD,      0x032A,   "Quadro NVS 280 PCI-E",            "Quadro NVS 280 PCI-E"            },
  { 0x00FD,      0x032B,   "Quadro FX 330",                   "Quadro FX 330"                   },
  { 0x00FE,      0x0000,   "Quadro FX 1300",                  "Quadro FX 1300"                  },
  { 0x00FE,      0x0338,   "Quadro FX 1300",                  "Quadro FX 1300"                  },
  { 0x00FF,      0x0000,   "GeForce PCX 4300",                "GeForce PCX 4300"                },
  { 0x00FF,      0x0181,   "GeForce PCX 4300",                "GeForce PCX 4300"                },
  { 0x0316,      0x0000,   "NV31M",                           "NV31M"                           },
  { 0x0317,      0x0000,   "NV31M Pro",                       "NV31M Pro"                       },
  { 0x031D,      0x0000,   "NV31GLM",                         "NV31GLM"                         },
  { 0x031E,      0x0000,   "NV31GLM Pro",                     "NV31GLM Pro"                     },
  { 0x031F,      0x0000,   "NV31GLM Pro",                     "NV31GLM Pro"                     },
  { 0x0329,      0x0000,   "NV34MAP",                         "NV34MAP"                         },
  { 0x0349,      0x0000,   "NV36M Pro",                       "NV36M Pro"                       },
  { 0x034B,      0x0000,   "NV36MAP",                         "NV36MAP"                         },
  { 0x0140,      0x0000,   "NV43",                            "NV43"                            },
  { 0x0147,      0x0000,   "NV43",                            "NV43"                            },
  { 0x0149,      0x0000,   "NV43",                            "NV43"                            },
  { 0x014C,      0x0000,   "NV43GL",                          "NV43GL"                          },
  { 0x0169,      0x0000,   "NV44M",                           "NV44M"                           },
  { 0x016B,      0x0000,   "NV44GLM",                         "NV44GLM"                         },
  { 0x016C,      0x0000,   "NV44GLM",                         "NV44GLM"                         },
  { 0x016D,      0x0000,   "NV44GLM",                         "NV44GLM"                         },
  { 0x0228,      0x0000,   "NV44M",                           "NV44M"                           },
  { 0x009D,      0x0000,   "Quadro FX 4500",                  "Quadro FX 4500"                  },
  { 0x0090,      0x0000,   "GeForce 7800 GTX 512",            "GeForce 7800 GTX 512"            },
  { 0x0091,      0x0000,   "GeForce 7800 GTX",                "GeForce 7800 GTX"                },
  { 0x0092,      0x0000,   "GeForce 7800 GT",                 "GeForce 7800 GT"                 },
  { 0x0093,      0x0000,   "GeForce 7800 GS",                 "GeForce 7800 GS"                 },
  { 0x0290,      0x0000,   "GeForce 7900 GTX",                "GeForce 7900 GTX"                },
  { 0x0291,      0x0000,   "GeForce 7900 GT",                 "GeForce 7900 GT"                 },
  { 0x0292,      0x0000,   "GeForce 7900 GS",                 "GeForce 7900 GS"                 },
  { 0x0293,      0x0000,   "GeForce 7950 GX2",                "GeForce 7950 GX2"                },
  { 0x0294,      0x0000,   "GeForce 7950 GX2",                "GeForce 7950 GX2"                },
  { 0x0295,      0x0000,   "GeForce 7950 GT",                 "GeForce 7950 GT"                 },
  { 0x01D1,      0x0000,   "GeForce 7300 LE",                 "GeForce 7300 LE"                 },
  { 0x01D3,      0x0000,   "GeForce 7300 SE",                 "GeForce 7300 SE"                 },
  { 0x01DF,      0x0000,   "GeForce 7300 GS",                 "GeForce 7300 GS"                 },
  { 0x0391,      0x0000,   "GeForce 7600 GT",                 "GeForce 7600 GT"                 },
  { 0x0393,      0x0000,   "GeForce 7300 GT",                 "GeForce 7300 GT"                 },
  { 0x0395,      0x0000,   "GeForce 7300 GT",                 "GeForce 7300 GT"                 },
  { 0x0191,      0x0000,   "GeForce 8800 GTX",                "GeForce 8800 GTX"                },
  { 0x0193,      0x0000,   "GeForce 8800 GTS",                "GeForce 8800 GTS"                },

// Mobile:
  { 0x0112,      0x0000,   "GeForce2 Go",                     "GeForce2 Go"                     },
  { 0x0174,      0x0000,   "GeForce4 440 Go",                 "GeForce4 440 Go"                 },
  { 0x0175,      0x0000,   "GeForce4 420 Go",                 "GeForce4 420 Go"                 },
  { 0x0176,      0x0000,   "GeForce4 420 Go 32M",             "GeForce4 420 Go 32M"             },
  { 0x0177,      0x0000,   "GeForce4 460 Go",                 "GeForce4 460 Go"                 },
  { 0x0179,      0x0000,   "GeForce4 440 Go 64M",             "GeForce4 440 Go 64M"             },
  { 0x017D,      0x0000,   "GeForce4 410 Go 16M",             "GeForce4 410 Go 16M"             },
  { 0x017C,      0x0000,   "Quadro4 500 GoGL",                "Quadro4 500 GoGL"                },
  { 0x0186,      0x0000,   "GeForce4 448 Go",                 "GeForce4 448 Go"                 },
  { 0x0187,      0x0000,   "GeForce4 488 Go",                 "GeForce4 488 Go"                 },
  { 0x018D,      0x0000,   "GeForce4 448 Go",                 "GeForce4 448 Go"                 },
  { 0x0286,      0x0000,   "GeForce4 4200 Go",                "GeForce4 4200 Go"                },
  { 0x028C,      0x0000,   "Quadro4 700 GoGL",                "Quadro4 700 GoGL"                },
  { 0x031A,      0x0000,   "GeForce FX Go5600",               "GeForce FX Go5600"               },
  { 0x031B,      0x0000,   "GeForce FX Go5650",               "GeForce FX Go5650"               },
  { 0x031C,      0x0000,   "Quadro FX Go700",                 "Quadro FX Go700"                 },
  { 0x0324,      0x0000,   "GeForce FX Go5200",               "GeForce FX Go5200"               },
  { 0x0325,      0x0000,   "GeForce FX Go5250",               "GeForce FX Go5250"               },
  { 0x0328,      0x0000,   "GeForce FX Go5200 32M/64M",       "GeForce FX Go5200 32M/64M"       },
  { 0x032C,      0x0000,   "GeForce FX Go53xx",               "GeForce FX Go53xx"               },
  { 0x032D,      0x0000,   "GeForce FX Go5100",               "GeForce FX Go5100"               },
  { 0x0347,      0x0000,   "GeForce FX Go5700",               "GeForce FX Go5700"               },
  { 0x0348,      0x0000,   "GeForce FX Go5700",               "GeForce FX Go5700"               },
  { 0x034C,      0x0000,   "Quadro FX Go1000",                "Quadro FX Go1000"                },
  { 0x00C8,      0x0000,   "GeForce Go 6800",                 "GeForce Go 6800"                 },
  { 0x00C9,      0x0000,   "GeForce Go 6800 Ultra",           "GeForce Go 6800 Ultra"           },
  { 0x00CC,      0x0000,   "Quadro FX Go1400",                "Quadro FX Go1400"                },
  { 0x0144,      0x0000,   "GeForce Go 6600",                 "GeForce Go 6600"                 },
  { 0x0146,      0x0000,   "GeForce Go 6600 TE/6200 TE",      "GeForce Go 6600 TE/6200 TE"      },
  { 0x0148,      0x0000,   "GeForce Go 6600",                 "GeForce Go 6600"                 },
  { 0x0149,      0x0000,   "GeForce Go 6600 GT",              "GeForce Go 6600 GT"              },
  { 0x0164,      0x0000,   "GeForce Go 6200",                 "GeForce Go 6200"                 },
  { 0x0166,      0x0000,   "GeForce Go 6400",                 "GeForce Go 6400"                 },
  { 0x0167,      0x0000,   "GeForce Go 6200",                 "GeForce Go 6200"                 },
  { 0x0168,      0x0000,   "GeForce Go 6400",                 "GeForce Go 6400"                 },
  { 0x0098,      0x0000,   "GeForce Go 7800",                 "GeForce Go 7800"                 },
  { 0x0099,      0x0000,   "GeForce Go 7800 GTX",             "GeForce Go 7800 GTX"             },

};

#endif /* NVIDIA_DEVICE_INFO_H */